from setuptools import setup

setup(name='distributions_GMG',
      version='0.1',
      description='Gaussian distributions',
      packages=['distributions_GMG'],
      author = "Gonzalo Munilla Garrido",
      zip_safe=False)
